@@ -85,7 +85,8 @@ imgparam_window_show (ImgparamWindow *self)
 
     if (priv->enabled) {
     	imgparam_window_set_position (self);
-    	gtk_widget_show (priv->overlay);
+    	// gtk_widget_show (priv->overlay);
+    	gtk_window_present (GTK_WINDOW (priv->overlay));
     }
 }
 
