@@ -69,7 +69,7 @@ void create_app(app_data_t *myapp) {
     g_signal_connect_after(G_OBJECT (openitem),"clicked",G_CALLBACK (open_image_file),myapp);
     hildon_app_menu_insert(appmenu,GTK_BUTTON(openitem),0);
 
-    imgdetitem = gtk_button_new_with_label((myapp->showimgparam ? "Hide details" : "View details"));
+    imgdetitem = gtk_button_new_with_label((myapp->showimgparam ? "Hide details" : "Show details"));
     g_signal_connect_after(G_OBJECT (imgdetitem),"clicked",G_CALLBACK (toggle_image_details),myapp);
     hildon_app_menu_insert(appmenu,GTK_BUTTON (imgdetitem),1);
 
@@ -118,7 +118,8 @@ void create_app(app_data_t *myapp) {
 
     /* Create image parameters window */
     myapp->imgparamwin = imgparam_window_new(GTK_WINDOW (myapp->mainwin),NULL);
-    if (myapp->showimgparam) g_object_set(G_OBJECT (myapp->imgparamwin),"enabled",TRUE,NULL);
+    myapp->showimgparam = !myapp->showimgparam;
+    toggle_image_details(GTK_WIDGET (myapp->mainwin),myapp);
 
     /* Save list of known image files in current directory */
 	store_filenames_in_dir(myapp);
